@@ -1,14 +1,8 @@
-from typing import Callable, Dict, List, Tuple, Union
+from typing import Callable
 
 import torch
 import torch.nn as nn
-from captum.attr import (
-    IntegratedGradients,
-    LayerConductance,
-    LayerIntegratedGradients,
-    configure_interpretable_embedding_layer,
-    remove_interpretable_embedding_layer,
-)
+from captum.attr import LayerIntegratedGradients
 from captum.attr import visualization as viz
 
 from transformers_interpret.errors import AttributionsNotCalculatedError
@@ -99,10 +93,10 @@ class LIGAttributions(Attributions):
         else:
             raise AttributionsNotCalculatedError("Attributions are not yet calculated")
 
-    def summarize(self):
+    def summarize(self, end_idx=None):
         self.attributions_sum = self._attributions.sum(dim=-1).squeeze(0)
-        self.attributions_sum = self.attributions_sum / torch.norm(
-            self.attributions_sum
+        self.attributions_sum = self.attributions_sum[:end_idx] / torch.norm(
+            self.attributions_sum[:end_idx]
         )
 
     def visualize_attributions(
